//---------------------------------------------------------------------------------------
//  FILE:   XComDownloadableContentInfo_AchievementUnlocker.uc                                    
//           
//	Use the X2DownloadableContentInfo class to specify unique mod behavior when the 
//  player creates a new campaign or loads a saved game.
//  
//---------------------------------------------------------------------------------------
//  Copyright (c) 2016 Firaxis Games, Inc. All rights reserved.
//---------------------------------------------------------------------------------------

class X2DownloadableContentInfo_AchievementUnlocker extends X2DownloadableContentInfo;

/// <summary>
/// This method is run if the player loads a saved game that was created prior to this DLC / Mod being installed, and allows the 
/// DLC / Mod to perform custom processing in response. This will only be called once the first time a player loads a save that was
/// create without the content installed. Subsequent saves will record that the content was installed.
/// </summary>
static event OnLoadedSavedGame()
{}

/// <summary>
/// Called when the player starts a new campaign while this DLC / Mod is installed
/// </summary>
static event InstallNewCampaign(XComGameState StartState)
{
`ONLINEEVENTMGR.UnlockAchievement(AT_BeatMissionJuneOrLater);
`ONLINEEVENTMGR.UnlockAchievement(AT_SabotageFacility);
`ONLINEEVENTMGR.UnlockAchievement(AT_RecoverForgeItem);
`ONLINEEVENTMGR.UnlockAchievement(AT_RecoverPsiGate);
`ONLINEEVENTMGR.UnlockAchievement(AT_RecoverBlackSiteData);
`ONLINEEVENTMGR.UnlockAchievement(AT_RecoverCodexBrain);
`ONLINEEVENTMGR.UnlockAchievement(AT_BeatMissionNoCivilianDeath);
`ONLINEEVENTMGR.UnlockAchievement(AT_BeatMissionSameClass);
`ONLINEEVENTMGR.UnlockAchievement(AT_TripleKill);
`ONLINEEVENTMGR.UnlockAchievement(AT_Kill500);
`ONLINEEVENTMGR.UnlockAchievement(AT_KillWithEveryHeavyWeapon);
`ONLINEEVENTMGR.UnlockAchievement(AT_Ambush);
`ONLINEEVENTMGR.UnlockAchievement(AT_KillAvatar);
`ONLINEEVENTMGR.UnlockAchievement(AT_KillBerserkerMelee);
`ONLINEEVENTMGR.UnlockAchievement(AT_KillSectoidMindControlling);
`ONLINEEVENTMGR.UnlockAchievement(AT_InstaKillSectopod);
`ONLINEEVENTMGR.UnlockAchievement(AT_KillViperStrangling);
`ONLINEEVENTMGR.UnlockAchievement(AT_KillViaFalling);
`ONLINEEVENTMGR.UnlockAchievement(AT_KillViaCarExplosion);
`ONLINEEVENTMGR.UnlockAchievement(AT_OverthrowAny);
`ONLINEEVENTMGR.UnlockAchievement(AT_OverthrowClassic);
`ONLINEEVENTMGR.UnlockAchievement(AT_WinGameClassicWithoutBuyingUpgrade);
`ONLINEEVENTMGR.UnlockAchievement(AT_WinGameClassicPlusByDate);
`ONLINEEVENTMGR.UnlockAchievement(AT_Ironman);
`ONLINEEVENTMGR.UnlockAchievement(AT_WinGameClassicPlusNoLosses);
`ONLINEEVENTMGR.UnlockAchievement(AT_OverthrowImpossible);
`ONLINEEVENTMGR.UnlockAchievement(AT_WinGameUsingConventionalGear);
`ONLINEEVENTMGR.UnlockAchievement(AT_SkulljackEachAdventSoldierType);
`ONLINEEVENTMGR.UnlockAchievement(AT_GuerillaWarfare);
`ONLINEEVENTMGR.UnlockAchievement(AT_ApplyPCSUpgrade);
`ONLINEEVENTMGR.UnlockAchievement(AT_UpgradeWeapon);
`ONLINEEVENTMGR.UnlockAchievement(AT_UpgradeWeaponSuperior);
`ONLINEEVENTMGR.UnlockAchievement(AT_BuildResistanceComms);
`ONLINEEVENTMGR.UnlockAchievement(AT_BuildShadowChamber);
`ONLINEEVENTMGR.UnlockAchievement(AT_BuildEverySlot);
`ONLINEEVENTMGR.UnlockAchievement(AT_UpgradeFacility);
`ONLINEEVENTMGR.UnlockAchievement(AT_CompletePOI);
`ONLINEEVENTMGR.UnlockAchievement(AT_ContactRegion);
`ONLINEEVENTMGR.UnlockAchievement(AT_BuildRadioEveryContinent);
`ONLINEEVENTMGR.UnlockAchievement(AT_GetAllContinentBonuses);
`ONLINEEVENTMGR.UnlockAchievement(AT_CompleteAvatarAutopsy);
`ONLINEEVENTMGR.UnlockAchievement(AT_BlackMarket);
`ONLINEEVENTMGR.UnlockAchievement(AT_CreateDarkVolunteer);
`ONLINEEVENTMGR.UnlockAchievement(AT_Hacker);
`ONLINEEVENTMGR.UnlockAchievement(AT_HackGain3Rewards);
`ONLINEEVENTMGR.UnlockAchievement(AT_WinMultiplayerMatch);
`ONLINEEVENTMGR.UnlockAchievement(AT_CompleteTutorial);
`ONLINEEVENTMGR.UnlockAchievement(AT_EvacRescue);
`ONLINEEVENTMGR.UnlockAchievement(AT_KillWithHackedTurret);
}